@@ -115,18 +115,43 @@ class web:
 
         name: python命令行解释机名字 默认python3
         """
-        if self.__config.app['app_debug']:
-            arg=sys.argv
-            if len(arg)==2 and arg[1]=='eventlog':
-                self.__impl(host=host,port=port,filename=filename)
+        if len(sys.argv)==1 or (len(sys.argv)==2 and sys.argv[1]=='eventlog'):
+            if self.__config.app['app_debug']:
+                arg=sys.argv
+                if len(arg)==2 and arg[1]=='eventlog':
+                    self.__impl(host=host,port=port,filename=filename)
+                else:
+                    Events([name,str(filename)+'.py','eventlog'])
             else:
-                Events([name,str(filename)+'.py','eventlog'])
+                self.__impl(
+                    host=host,
+                    port=port,
+                    filename=filename
+                )
         else:
-            self.__impl(
-                host=host,
-                port=port,
-                filename=filename
-            )
+            try:
+                RAW_URI=sys.argv[1]
+            except:pass
+            else:
+                PATH_INFO=RAW_URI.split("?")[0] #/aa/bb/cc
+                if PATH_INFO[0]=='/':
+                    PATH_INFO=PATH_INFO[1:]
+                QUERY_STRING=RAW_URI.replace(str(PATH_INFO),'').replace('?','') #a=1&b=1
+                reqheader={ 
+                    'REQUEST_METHOD':'GET',
+                    'RAW_URI':RAW_URI,
+                    'PATH_INFO':PATH_INFO,
+                    'QUERY_STRING':QUERY_STRING,
+                    'SERVER_PROTOCOL':'',
+                    'HTTP_HOST':'',
+                    'HTTP_COOKIE':'',
+                    'REMOTE_ADDR':'',
+                    'HTTP_USER_AGENT':'',
+                    'BODY_DATA':''
+                }
+                status,resheader,body=self.__routes(reqheader)
+                print(body)
+            exit()
     def __impl(self,host,port,filename):
         "运行测试服务器"
         try:
@@ -630,7 +655,6 @@ class web:
                 'HTTP_USER_AGENT':HTTP_USER_AGENT,
                 'BODY_DATA':BODY_DATA
             }
-            # print(BODY_DATA)
             p=(config.app['staticpath']+RAW_URI.replace(' ',''))
             # print("目录",p)
             status='200 ok'
