@@ -88,9 +88,9 @@ email['recNick']='' #默认收件人昵称
 
 kcweb={}
 kcweb['name']='kcweb'                             #项目的名称
-kcweb['version']='2.40.1'							#项目版本
+kcweb['version']='2.40.2'							#项目版本
 kcweb['description']='基于python后端开发框架'       #项目的简单描述
-kcweb['long_description']='增加独立路由配置'     #项目详细描述
+kcweb['long_description']=''     #项目详细描述
 kcweb['license']='MIT'                    #开源协议   mit开源
 kcweb['url']='http://intapp.kwebapp.cn/index/index/doc/docde/1'
 kcweb['author']='禄可集团-坤坤'  					 #名字
