@@ -17,20 +17,6 @@ class create:
         self.modular=modular
         if not os.path.exists(self.appname):
             os.makedirs(self.appname)
-        if not os.path.exists(self.appname+"/script"):
-            os.makedirs(self.appname+"/script/common")
-            f=open(self.appname+"/script/common/__init__.py","w+",encoding='utf-8')
-            content=Template(self.path+"/application/script/common/__init__.py",appname=appname,modular=modular)
-            f.write(content)
-            f.close()
-            f=open(self.appname+"/script/common/win.py","w+",encoding='utf-8')
-            content=Template(self.path+"/application/script/common/win.py",appname=appname,modular=modular)
-            f.write(content)
-            f.close()
-            f=open(self.appname+"/script/test.py","w+",encoding='utf-8')
-            content=Template(self.path+"/application/script/test.py",appname=appname,modular=modular)
-            f.write(content)
-            f.close()
         if not os.path.exists(self.appname+"/common"):
             os.makedirs(self.appname+"/common")
             f=open(self.appname+"/common/__init__.py","w+",encoding='utf-8')
