@@ -21,13 +21,13 @@ class redis:
             else:
                 self.__redisObj=red.Redis(host=self.__config['host'],port=self.__config['port'],db=self.__config['db'])
             # print(self.__redisObj)
-    def json_decode(self,strs):
+    def __json_decode(self,strs):
         """json字符串转python类型"""
         try:
             return json.loads(strs)
         except Exception:
             return {}
-    def json_encode(self,strs):
+    def __json_encode(self,strs):
         """转成字符串"""
         try:
             return json.dumps(strs,ensure_ascii=False)
@@ -57,11 +57,11 @@ class redis:
         "得到一个redis连接对象，执行更多高级操作"
         self.__connects()
         return self.__redisObj
-    def set(self,name,value,ex=None, px=None, nx=False, xx=False):
+    def setstr(self,name,value,ex=None, px=None, nx=False, xx=False):
         """
         name，键
 
-        value，值
+        value，值 只能是字符串
 
         ex，过期时间（秒）
 
@@ -76,7 +76,37 @@ class redis:
         if not ex and not px:
             if self.__config['ex']:
                 ex=self.__config['ex']
-        value=self.json_encode(value)
+        return self.__redisObj.set(name, value, ex=ex, px=px, nx=nx, xx=xx)
+    def append(self,name,value):
+        """将字符串“value”追加到“name”处的值。如果``键`` 不存在，请使用值“name”创建它。 返回位于“name”的值的新长度。
+        
+        name，键
+
+        value，值 只能是字符串
+        """
+        self.__connects()
+        return self.__redisObj.append(name,value)
+    
+    def set(self,name,value,ex=None, px=None, nx=False, xx=False):
+        """
+        name，键
+
+        value，值 可以是字典 列表 或字符串
+
+        ex，过期时间（秒）
+
+        px，过期时间（毫秒）
+
+        nx，如果设置为True，则只有key不存在时，当前set操作才执行,同#setnx(key, value)
+
+        xx，如果设置为True，则只有key存在时，当前set操作才执行
+        """
+        if not self.__redisObj:
+            self.__connects()
+        if not ex and not px:
+            if self.__config['ex']:
+                ex=self.__config['ex']
+        value=self.__json_encode(value)
         return self.__redisObj.set(name, value, ex=ex, px=px, nx=nx, xx=xx)
     def get(self,name):
         """获取name的值
@@ -85,7 +115,7 @@ class redis:
         返回键“name”处的值，如果该键不存在，则返回“none”
         """
         self.__connects()
-        return self.json_decode(self.__redisObj.get(name))
+        return self.__json_decode(self.__redisObj.get(name))
     def delete(self,name):
         """删除name的值
 
@@ -124,6 +154,25 @@ class redis:
         "当name存在时，元素才能从list的左边加入"
         self.__connects()
         return self.__redisObj.lpushx(name)
+    def hset(self,name,key,value):
+        """在hash``名称中将'key``设置为'value`'``如果HSET创建了新字段，则返回1，否则返回0
+        
+        name，名
+
+        key，键
+
+        mapping，值
+        """
+        self.__connects()
+        return self.__redisObj.hset(name,key,value)
+    def hget(self,name,key):
+        "返回散列``name``中的``key``值"
+        self.__connects()
+        return self.__redisObj.hget(name,key)
+    def hgetall(self,name):
+        "返回散列名称/值对的Python dict"
+        self.__connects()
+        return self.__redisObj.hgetall(name)
     def hmset(self,name,mapping,ex=None):
         """在hash“name”中为每个键设置值
         name，键
@@ -146,3 +195,4 @@ class redis:
         "返回与“keys”顺序相同的值列表``"
         self.__connects()
         return self.__redisObj.hmget(name, keys, *args)
+    
